Stan Math Library: stan/math/rev/scal/fun/fma.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
fma.hpp File Reference
`#include <math.h>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <boost/math/special_functions/fpclassify.hpp>`
`#include <stan/math/prim/scal/meta/likely.hpp>`
`#include <valarray>`
`#include <limits>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
var | stan::math::fma (const stan::math::var &a, const stan::math::var &b, const stan::math::var &c)
| The fused multiply-add function for three variables (C99). More...
var | stan::math::fma (const stan::math::var &a, const stan::math::var &b, const double &c)
| The fused multiply-add function for two variables and a value (C99). More...
var | stan::math::fma (const stan::math::var &a, const double &b, const stan::math::var &c)
| The fused multiply-add function for a variable, value, and variable (C99). More...
var | stan::math::fma (const stan::math::var &a, const double &b, const double &c)
| The fused multiply-add function for a variable and two values (C99). More...
var | stan::math::fma (const double &a, const stan::math::var &b, const double &c)
| The fused multiply-add function for a value, variable, and value (C99). More...
var | stan::math::fma (const double &a, const double &b, const stan::math::var &c)
| The fused multiply-add function for two values and a variable, and value (C99). More...
var | stan::math::fma (const double &a, const stan::math::var &b, const stan::math::var &c)
| The fused multiply-add function for a value and two variables (C99). More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.